==> twisted-19.2.0-py37h1de35cc_0.tar.bz2: info/test/run_test.py <==
#  tests for twisted-19.2.0-py37h1de35cc_0 (this is a generated file);
print('===== testing package: twisted-19.2.0-py37h1de35cc_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import twisted
import os

print('twisted.__version__: %s' % twisted.__version__)
assert twisted.__version__ == os.getenv("PKG_VERSION")
#  --- run_test.py (end) ---

print('===== twisted-19.2.0-py37h1de35cc_0 OK =====');
print("import: 'twisted'")
import twisted

print("import: 'twisted._threads'")
import twisted._threads

print("import: 'twisted._threads.test'")
import twisted._threads.test

print("import: 'twisted.application'")
import twisted.application

print("import: 'twisted.application.runner'")
import twisted.application.runner

print("import: 'twisted.application.runner.test'")
import twisted.application.runner.test

print("import: 'twisted.application.test'")
import twisted.application.test

print("import: 'twisted.application.twist'")
import twisted.application.twist

print("import: 'twisted.application.twist.test'")
import twisted.application.twist.test

print("import: 'twisted.conch'")
import twisted.conch

print("import: 'twisted.conch.client'")
import twisted.conch.client

print("import: 'twisted.conch.insults'")
import twisted.conch.insults

print("import: 'twisted.conch.openssh_compat'")
import twisted.conch.openssh_compat

print("import: 'twisted.conch.scripts'")
import twisted.conch.scripts

print("import: 'twisted.conch.ssh'")
import twisted.conch.ssh

print("import: 'twisted.conch.test'")
import twisted.conch.test

print("import: 'twisted.conch.ui'")
import twisted.conch.ui

print("import: 'twisted.cred'")
import twisted.cred

print("import: 'twisted.cred.test'")
import twisted.cred.test

print("import: 'twisted.enterprise'")
import twisted.enterprise

print("import: 'twisted.internet'")
import twisted.internet

print("import: 'twisted.internet.test'")
import twisted.internet.test

print("import: 'twisted.logger'")
import twisted.logger

print("import: 'twisted.logger.test'")
import twisted.logger.test

print("import: 'twisted.mail'")
import twisted.mail

print("import: 'twisted.mail.test'")
import twisted.mail.test

print("import: 'twisted.names'")
import twisted.names

print("import: 'twisted.names.test'")
import twisted.names.test

print("import: 'twisted.pair'")
import twisted.pair

print("import: 'twisted.pair.test'")
import twisted.pair.test

print("import: 'twisted.persisted'")
import twisted.persisted

print("import: 'twisted.persisted.test'")
import twisted.persisted.test

print("import: 'twisted.plugins'")
import twisted.plugins

print("import: 'twisted.positioning'")
import twisted.positioning

print("import: 'twisted.positioning.test'")
import twisted.positioning.test

print("import: 'twisted.protocols'")
import twisted.protocols

print("import: 'twisted.protocols.haproxy'")
import twisted.protocols.haproxy

print("import: 'twisted.protocols.haproxy.test'")
import twisted.protocols.haproxy.test

print("import: 'twisted.protocols.test'")
import twisted.protocols.test

print("import: 'twisted.python'")
import twisted.python

print("import: 'twisted.python.test'")
import twisted.python.test

print("import: 'twisted.runner'")
import twisted.runner

print("import: 'twisted.runner.test'")
import twisted.runner.test

print("import: 'twisted.scripts'")
import twisted.scripts

print("import: 'twisted.scripts.test'")
import twisted.scripts.test

print("import: 'twisted.spread'")
import twisted.spread

print("import: 'twisted.spread.test'")
import twisted.spread.test

print("import: 'twisted.tap'")
import twisted.tap

print("import: 'twisted.test'")
import twisted.test

print("import: 'twisted.test.raiser'")
import twisted.test.raiser

print("import: 'twisted.trial'")
import twisted.trial

print("import: 'twisted.trial._dist'")
import twisted.trial._dist

print("import: 'twisted.trial._dist.test'")
import twisted.trial._dist.test

print("import: 'twisted.trial.test'")
import twisted.trial.test

print("import: 'twisted.web'")
import twisted.web

print("import: 'twisted.web._auth'")
import twisted.web._auth

print("import: 'twisted.web.test'")
import twisted.web.test

print("import: 'twisted.words'")
import twisted.words

print("import: 'twisted.words.im'")
import twisted.words.im

print("import: 'twisted.words.protocols'")
import twisted.words.protocols

print("import: 'twisted.words.protocols.jabber'")
import twisted.words.protocols.jabber

print("import: 'twisted.words.test'")
import twisted.words.test

print("import: 'twisted.words.xish'")
import twisted.words.xish

==> twisted-19.10.0-py37h1de35cc_0.tar.bz2: info/test/run_test.py <==
#  tests for twisted-19.10.0-py37h1de35cc_0 (this is a generated file);
print('===== testing package: twisted-19.10.0-py37h1de35cc_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import twisted
import os

print('twisted.__version__: %s' % twisted.__version__)
assert twisted.__version__ == os.getenv("PKG_VERSION")
#  --- run_test.py (end) ---

print('===== twisted-19.10.0-py37h1de35cc_0 OK =====');
print("import: 'twisted'")
import twisted

print("import: 'twisted._threads'")
import twisted._threads

print("import: 'twisted.application'")
import twisted.application

print("import: 'twisted.application.runner'")
import twisted.application.runner

print("import: 'twisted.application.twist'")
import twisted.application.twist

print("import: 'twisted.conch'")
import twisted.conch

print("import: 'twisted.conch.client'")
import twisted.conch.client

print("import: 'twisted.conch.insults'")
import twisted.conch.insults

print("import: 'twisted.conch.openssh_compat'")
import twisted.conch.openssh_compat

print("import: 'twisted.conch.scripts'")
import twisted.conch.scripts

print("import: 'twisted.conch.ssh'")
import twisted.conch.ssh

print("import: 'twisted.conch.ui'")
import twisted.conch.ui

print("import: 'twisted.cred'")
import twisted.cred

print("import: 'twisted.enterprise'")
import twisted.enterprise

print("import: 'twisted.internet'")
import twisted.internet

print("import: 'twisted.logger'")
import twisted.logger

print("import: 'twisted.mail'")
import twisted.mail

print("import: 'twisted.mail.scripts'")
import twisted.mail.scripts

print("import: 'twisted.names'")
import twisted.names

print("import: 'twisted.pair'")
import twisted.pair

print("import: 'twisted.persisted'")
import twisted.persisted

print("import: 'twisted.plugins'")
import twisted.plugins

print("import: 'twisted.positioning'")
import twisted.positioning

print("import: 'twisted.protocols'")
import twisted.protocols

print("import: 'twisted.protocols.haproxy'")
import twisted.protocols.haproxy

print("import: 'twisted.python'")
import twisted.python

print("import: 'twisted.runner'")
import twisted.runner

print("import: 'twisted.scripts'")
import twisted.scripts

print("import: 'twisted.spread'")
import twisted.spread

print("import: 'twisted.tap'")
import twisted.tap

print("import: 'twisted.trial'")
import twisted.trial

print("import: 'twisted.trial._dist'")
import twisted.trial._dist

print("import: 'twisted.web'")
import twisted.web

print("import: 'twisted.web._auth'")
import twisted.web._auth

print("import: 'twisted.words'")
import twisted.words

print("import: 'twisted.words.im'")
import twisted.words.im

print("import: 'twisted.words.protocols'")
import twisted.words.protocols

print("import: 'twisted.words.protocols.jabber'")
import twisted.words.protocols.jabber

print("import: 'twisted.words.xish'")
import twisted.words.xish
